@@ -14,7 +14,7 @@ use DBI;
 
 use vars qw($VERSION);
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 use constant {
     DATA => 2,
@@ -323,7 +323,7 @@ sub fetch {
     my( $class ) = $self->{DBH}->selectrow_array( "SELECT class FROM objects WHERE id=?", {}, $id );
     print STDERR Data::Dumper->Dump(["db __LINE__",$self->{DBH}->errstr()]) if $self->{DBH}->errstr();
 
-    return undef unless $class;
+    return unless $class;
     my $obj = [$id,$class];
     if( $class eq 'ARRAY') {
 	$obj->[DATA] = [];
@@ -493,7 +493,7 @@ sub path_to_root {
 	}
     }
 
-    return undef;
+    return;
 } #path_to_root
 
 #
